@@ -10,7 +10,6 @@ from typing import Optional
 from typing import Union
 
 
-from unittest import mock
 import asyncio
 import functools
 import inspect
@@ -35,8 +34,6 @@ def _get_mock_module(config):
 
             _get_mock_module._module = mock
         else:
-            import unittest.mock
-
             _get_mock_module._module = unittest.mock
 
     return _get_mock_module._module
@@ -68,6 +65,8 @@ class MockerFixture:
         self.create_autospec = mock_module.create_autospec
         self.sentinel = mock_module.sentinel
         self.mock_open = mock_module.mock_open
+        if hasattr(mock_module, "seal"):
+            self.seal = mock_module.seal
 
     def resetall(self) -> None:
         """Call reset_mock() on all patchers started by this fixture."""
@@ -91,7 +90,7 @@ class MockerFixture:
 
         :param object obj: An object.
         :param unicode name: A method in object.
-        :rtype: mock.MagicMock
+        :rtype: unittest.mock.MagicMock
         :return: Spy object.
         """
         method = getattr(obj, name)
@@ -115,7 +114,7 @@ class MockerFixture:
             spy_obj.spy_exception = None
             try:
                 r = method(*args, **kwargs)
-            except Exception as e:
+            except BaseException as e:
                 spy_obj.spy_exception = e
                 raise
             else:
@@ -127,7 +126,7 @@ class MockerFixture:
             spy_obj.spy_exception = None
             try:
                 r = await method(*args, **kwargs)
-            except Exception as e:
+            except BaseException as e:
                 spy_obj.spy_exception = e
                 raise
             else:
@@ -150,7 +149,7 @@ class MockerFixture:
         callbacks in tests.
 
         :param name: the constructed stub's name as used in repr
-        :rtype: mock.MagicMock
+        :rtype: unittest.mock.MagicMock
         :return: Stub object.
         """
         return cast(
@@ -352,11 +351,11 @@ def _mocker(pytestconfig: Any) -> Generator[MockerFixture, None, None]:
     result.stopall()
 
 
-mocker = pytest.yield_fixture()(_mocker)  # default scope is function
-class_mocker = pytest.yield_fixture(scope="class")(_mocker)
-module_mocker = pytest.yield_fixture(scope="module")(_mocker)
-package_mocker = pytest.yield_fixture(scope="package")(_mocker)
-session_mocker = pytest.yield_fixture(scope="session")(_mocker)
+mocker = pytest.fixture()(_mocker)  # default scope is function
+class_mocker = pytest.fixture(scope="class")(_mocker)
+module_mocker = pytest.fixture(scope="module")(_mocker)
+package_mocker = pytest.fixture(scope="package")(_mocker)
+session_mocker = pytest.fixture(scope="session")(_mocker)
 
 
 _mock_module_patches = []  # type: List[Any]
